@@ -1,4 +1,4 @@
-catminat<-function(species_list,TRAITS,catminat_df){
+catminat<-function(species_list,TRAITS,catminat_df,similar=FALSE){
     res<-new("results")
     ## env<-new.env(parent = parent.frame())
     ## load(local_Catminat,envir = env)
@@ -8,8 +8,20 @@ catminat<-function(species_list,TRAITS,catminat_df){
         res@results<-NULL
     }else{
 
-        
-        DF<-catminat_df[catminat_df$species_name%in%species_list,c("species_name",TRAITS)]
+        if(similar){
+
+            DF<-lapply(species_list,function(x){
+                catminat_df[grep(x,catminat_df$species_name),c("species_name",TRAITS)]
+            }
+            )
+            DF<-ldply(DF)
+
+            }else{
+                DF<-catminat_df[catminat_df$species_name%in%species_list,c("species_name",TRAITS)]
+                }
+        ## in a few cases (e.g. Alnus viridis) some entries are double-> this causes
+        ## problems -> be sure that all rows are unique
+        DF<-unique(DF)
         row.names(DF)<-DF$species_name
         DF<-DF[,TRAITS,drop=FALSE]
 
