@@ -4,11 +4,16 @@ retrieve_MycoFlor<-function(species,TRAITS,rest,data_myco){
     if(is.null(TRAITS)){
         results<-NULL
     }else{
-        temp_df<-data_myco[data_myco$Plant.species%in%species,]
-        row.names(temp_df)<-temp_df$Plant.species
-        res_df<-data.frame(temp_df[,"Mycorrhizal.status",drop=FALSE])
-        names(res_df)<-"MycoFlor"
-        results<-res_df
+        temp_df<-as.data.frame(species,row.names = species)
+        res_df<-data_myco[data_myco$Plant.species%in%species,]
+        res_df<-merge(temp_df,res_df,by.x=0,by.y="Plant.species",all.x=TRUE)
+        res_df$Plant.species<-as.character(res_df$species)
+        temp_df<-with(res_df,tapply(Mycorrhizal.status,species,FUN = function(x){paste(unique(x),collapse = "-")}))
+        temp_df<-as.data.frame(temp_df)
+
+        names(temp_df)<-"MycoFlor"
+        results<-temp_df
+
     }
     res@results<-results
     ## remove(list=c("myco"),pos =".GlobalEnv")
